@@ -53,6 +53,7 @@ extractPrediction <- function(
               pred <- c(pred, as.character(tempTrainPred))
               obs <- c(obs, as.character(trainY))
             } else {
+              tempTrainPred <- trimPredictions(models[[i]], tempTrainPred)
               pred <- c(pred, tempTrainPred)
               obs <- c(obs, trainY)      
             }
@@ -83,6 +84,7 @@ extractPrediction <- function(
                   pred <- c(pred, as.character(tempTestPred))
                   obs <- c(obs, as.character(tempY))    
                 } else {
+                  tempTestPred <- trimPredictions(models[[i]], tempTestPred)
                   pred <- c(pred, tempTestPred)   
                   obs <- c(obs, tempY) 
                 }
@@ -115,6 +117,7 @@ extractPrediction <- function(
               pred <- c(pred, as.character(tempUnkPred))
               obs <- c(obs, rep("", length(tempUnkPred)))    
             } else {
+              tempUnkPred <- trimPredictions(models[[i]], tempUnkPred)
               pred <- c(pred, tempUnkPred)   
               obs <- c(obs, rep(NA, length(tempUnkPred)))    
             }
@@ -139,3 +142,24 @@ extractPrediction <- function(
              object = objName)
 }
 
+
+trimPredictions <- function(object, pred)
+  {
+    if(object$modelType == "Regression" &&
+       is.logical(object$control$predictionBounds) &&
+       any(object$control$predictionBounds))
+      {
+        if(object$control$predictionBounds[1]) pred <- ifelse(pred < object$yLimit[1], object$yLimit[1], pred)
+        if(object$control$predictionBounds[2]) pred <- ifelse(pred > object$yLimit[2], object$yLimit[2], pred)         
+      }
+    if(object$modelType == "Regression" &&
+       is.numeric(object$control$predictionBounds) &&
+       any(!is.na(object$control$predictionBounds)))
+      {
+        if(!is.na(object$control$predictionBounds[1])) pred <- ifelse(pred < object$control$predictionBounds[1], object$control$predictionBounds[1], pred)
+        if(!is.na(object$control$predictionBounds[2])) pred <- ifelse(pred > object$control$predictionBounds[2], object$control$predictionBounds[2], pred)
+      }
+    pred
+
+  }
+
