@@ -89,24 +89,20 @@ probFunction <- function(method, modelFit, newdata, preProc = NULL, param = NULL
                         library(gbm)
                         out <- predict(modelFit, newdata, type = "response",
                                        n.trees = modelFit$tuneValue$.n.trees)
-                        out <- cbind(out, 1-out)
-                        dimnames(out)[[2]] <-  modelFit$obsLevels
+                        out <- data.frame(a = out, b = 1-out)
+                        names(out) <-  modelFit$obsLevels
                         if(!is.null(param))
                           {
-                            tmp <- vector(mode = "list", length = nrow(param) + 1)
-                            tmp[[1]] <- out
-                            
-                            for(j in seq(along = param$.n.trees))
-                              {
-                                if(modelFit$problemType == "Classification")
-                                  {
-                                    gbmProb <- predict(modelFit, newdata, type = "response", n.trees = param$.n.trees[j])
-                                    gbmProb <- cbind(gbmProb, 1-gbmProb)
-                                    dimnames(gbmProb)[[2]] <-  modelFit$obsLevels
-                                    tmp[[j+1]] <- as.data.frame(gbmProb)
-                                  }
-                              }
-                            out <- tmp
+                            preds <- predict(modelFit, newdata, type = "response", n.trees = param$.n.trees)
+                            preds <- as.list(as.data.frame(preds))
+                            preds <- lapply(preds,
+                                            function(x, lev = modelFit$obsLevels)
+                                            {
+                                              out <- data.frame(a = x, b = 1 - x)
+                                              colnames(out) <- lev
+                                              out
+                                            })
+                            out <- c(list(out), preds)                
                           }
                         out
                       },
@@ -240,7 +236,7 @@ probFunction <- function(method, modelFit, newdata, preProc = NULL, param = NULL
                             for(j in seq(along = param$.nprune))
                               {
                                 prunedFit <- update(modelFit, nprune = param$.nprune[j])
-                                tmp2 <- predict(modelFit, newdata, type= "response")
+                                tmp2 <- predict(prunedFit, newdata, type= "response")
                                 tmp2 <- cbind(1-tmp2, tmp2)
                                 colnames(tmp2) <-  modelFit$obsLevels
                                 tmp[[j+1]] <- tmp2
